@@ -93,7 +93,39 @@ from rapida.clients.endpoint import (
 from rapida.clients.invoke import invoke
 
 
-# # Protobuf imports
+# # Protobuf imports - Import common_pb2 FIRST since other protos depend on it
+from rapida.clients.protos.common_pb2 import (
+    FieldSelector,
+    Criteria,
+    Error,
+    Paginate,
+    Paginated,
+    Ordering,
+    User,
+    BaseResponse,
+    Metadata,
+    Argument,
+    Variable,
+    Tag,
+    Organization,
+    Metric,
+    Message as ProtoMessage,
+    ToolCall,
+    FunctionCall,
+    Knowledge,
+    TextPrompt,
+    TextChatCompletePrompt,
+    AssistantConversationMessage,
+    AssistantConversationContext,
+    AssistantConversation,
+    GetAllAssistantConversationRequest,
+    GetAllAssistantConversationResponse,
+    GetAllConversationMessageRequest,
+    GetAllConversationMessageResponse,
+    AssistantDefinition,
+)
+
+# Now import other protos that may depend on common_pb2
 from rapida.clients.protos.assistant_knowledge_pb2 import (
     AssistantKnowledge,
     CreateAssistantKnowledgeRequest,
@@ -104,45 +136,24 @@ from rapida.clients.protos.assistant_knowledge_pb2 import (
     GetAllAssistantKnowledgeRequest,
     GetAllAssistantKnowledgeResponse,
 )
-from rapida.clients.protos.marketplace_api_pb2 import (
-    GetAllDeploymentRequest,
-    SearchableDeployment,
-    GetAllDeploymentResponse,
-)
-from rapida.clients.protos.audit_logging_api_pb2 import (
-    AuditLog,
-    GetAllAuditLogRequest,
-    GetAllAuditLogResponse,
-    GetAuditLogRequest,
-    GetAuditLogResponse,
-    CreateMetadataRequest,
-    CreateMetadataResponse,
-)
-from rapida.clients.protos.provider_api_pb2 import (
-    GetAllModelProviderRequest,
-    GetAllModelProviderResponse,
-    ToolProvider,
-    GetAllToolProviderRequest,
-    GetAllToolProviderResponse,
-)
+# from rapida.clients.protos.audit_logging_api_pb2 import (
+#     AuditLog,
+#     GetAllAuditLogRequest,
+#     GetAllAuditLogResponse,
+#     GetAuditLogRequest,
+#     GetAuditLogResponse,
+#     CreateMetadataRequest,
+#     CreateMetadataResponse,
+# )
 from rapida.clients.protos.vault_api_pb2 import (
     VaultCredential,
     CreateProviderCredentialRequest,
-    CreateToolCredentialRequest,
     DeleteCredentialRequest,
     GetAllOrganizationCredentialResponse,
-    GetProviderCredentialRequest,
     GetCredentialResponse,
     GetAllOrganizationCredentialRequest,
 )
 from rapida.clients.protos.talk_api_pb2 import (
-    AssistantDefinition,
-    AssistantMessagingRequest,
-    AssistantConversationConfiguration,
-    AssistantConversationInterruption,
-    AssistantConversationUserMessage,
-    AssistantConversationAssistantMessage,
-    AssistantMessagingResponse,
     CreateMessageMetricRequest,
     CreateMessageMetricResponse,
     CreateConversationMetricRequest,
@@ -151,6 +162,17 @@ from rapida.clients.protos.talk_api_pb2 import (
     CreateBulkPhoneCallResponse,
     CreatePhoneCallRequest,
     CreatePhoneCallResponse,
+    AssistantTalkInput,
+    AssistantTalkOutput,
+    TalkInput,
+    TalkOutput,
+    ConversationAssistantMessage,
+    ConversationConfiguration,
+    ConversationDirective,
+    ConversationInterruption,
+    ConversationUserMessage,
+    ConversationToolCall,
+    ConversationToolResult
 )
 from rapida.clients.protos.assistant_analysis_pb2 import (
     AssistantAnalysis,
@@ -162,15 +184,6 @@ from rapida.clients.protos.assistant_analysis_pb2 import (
     GetAllAssistantAnalysisRequest,
     GetAllAssistantAnalysisResponse,
 )
-from rapida.clients.protos.sendgrid_api_pb2 import (
-    Contact,
-    WelcomeEmailRequest,
-    WelcomeEmailResponse,
-    ResetPasswordEmailRequest,
-    ResetPasswordEmailResponse,
-    InviteMemeberEmailRequest,
-    InviteMemeberEmailResponse,
-)
 from rapida.clients.protos.invoker_api_pb2 import (
     EndpointDefinition,
     InvokeRequest,
@@ -189,7 +202,6 @@ from rapida.clients.protos.web_api_pb2 import (
     FeaturePermission,
     Authentication,
     ScopedAuthentication,
-    AuthenticationError,
     AuthenticateResponse,
     ForgotPasswordRequest,
     ForgotPasswordResponse,
@@ -207,7 +219,6 @@ from rapida.clients.protos.web_api_pb2 import (
     SocialAuthenticationRequest,
     GetAllUserRequest,
     GetAllUserResponse,
-    OrganizationError,
     CreateOrganizationRequest,
     UpdateOrganizationRequest,
     GetOrganizationRequest,
@@ -234,40 +245,6 @@ from rapida.clients.protos.web_api_pb2 import (
     CreateProjectCredentialResponse,
     GetAllProjectCredentialResponse,
 )
-from rapida.clients.protos.common_pb2 import (
-    FieldSelector,
-    Criteria,
-    Error,
-    Paginate,
-    Paginated,
-    Ordering,
-    User,
-    BaseResponse,
-    Metadata,
-    Argument,
-    Variable,
-    Provider,
-    Tag,
-    Organization,
-    Metric,
-    Content,
-    Message as ProtoMessage,
-    ToolCall,
-    FunctionCall,
-    Knowledge,
-    TextPrompt,
-    TextChatCompletePrompt,
-    AssistantMessageStage,
-    AssistantConversationMessage,
-    AssistantConversationContext,
-    AssistantConversation,
-    GetAllAssistantConversationRequest,
-    GetAllAssistantConversationResponse,
-    GetAllConversationMessageRequest,
-    GetAllConversationMessageResponse,
-    AssistantConversationMessageTextContent,
-    AssistantConversationMessageAudioContent,
-)
 from rapida.clients.protos.assistant_webhook_pb2 import (
     AssistantWebhook,
     AssistantWebhookLog,
@@ -284,12 +261,8 @@ from rapida.clients.protos.assistant_webhook_pb2 import (
     GetAllAssistantWebhookLogResponse,
 )
 from rapida.clients.protos.connect_api_pb2 import (
-    KnowledgeConnectRequest,
-    KnowledgeConnectResponse,
     GeneralConnectRequest,
     GeneralConnectResponse,
-    ActionConnectRequest,
-    ActionConnectResponse,
     GetConnectorFilesRequest,
     GetConnectorFilesResponse,
 )
@@ -411,6 +384,15 @@ from rapida.clients.protos.talk_api_pb2_grpc import (
     add_AgentKitServicer_to_server,
     )
 
+# Agent Kit classes
+from rapida.agentkit import (
+    AgentKitAgent,
+    AgentKitServer,
+    SSLConfig,
+    AuthConfig,
+    AuthorizationInterceptor,
+)
+
 __all__ = [
     "Any",
     "RapidaSource",
@@ -483,36 +465,19 @@ __all__ = [
     "GetAssistantKnowledgeResponse",
     "GetAllAssistantKnowledgeRequest",
     "GetAllAssistantKnowledgeResponse",
-    "GetAllDeploymentRequest",
-    "SearchableDeployment",
-    "GetAllDeploymentResponse",
     "AuditLog",
     "GetAllAuditLogRequest",
     "GetAllAuditLogResponse",
     "GetAuditLogRequest",
     "GetAuditLogResponse",
     "CreateMetadataRequest",
-    "CreateMetadataResponse",
-    "GetAllModelProviderRequest",
-    "GetAllModelProviderResponse",
-    "ToolProvider",
-    "GetAllToolProviderRequest",
-    "GetAllToolProviderResponse",
     "VaultCredential",
     "CreateProviderCredentialRequest",
-    "CreateToolCredentialRequest",
     "DeleteCredentialRequest",
     "GetAllOrganizationCredentialResponse",
-    "GetProviderCredentialRequest",
     "GetCredentialResponse",
     "GetAllOrganizationCredentialRequest",
     "AssistantDefinition",
-    "AssistantMessagingRequest",
-    "AssistantConversationConfiguration",
-    "AssistantConversationInterruption",
-    "AssistantConversationUserMessage",
-    "AssistantConversationAssistantMessage",
-    "AssistantMessagingResponse",
     "CreateMessageMetricRequest",
     "CreateMessageMetricResponse",
     "CreateConversationMetricRequest",
@@ -529,13 +494,6 @@ __all__ = [
     "GetAssistantAnalysisResponse",
     "GetAllAssistantAnalysisRequest",
     "GetAllAssistantAnalysisResponse",
-    "Contact",
-    "WelcomeEmailRequest",
-    "WelcomeEmailResponse",
-    "ResetPasswordEmailRequest",
-    "ResetPasswordEmailResponse",
-    "InviteMemeberEmailRequest",
-    "InviteMemeberEmailResponse",
     "EndpointDefinition",
     "InvokeRequest",
     "InvokeResponse",
@@ -551,7 +509,6 @@ __all__ = [
     "FeaturePermission",
     "Authentication",
     "ScopedAuthentication",
-    "AuthenticationError",
     "AuthenticateResponse",
     "ForgotPasswordRequest",
     "ForgotPasswordResponse",
@@ -569,7 +526,6 @@ __all__ = [
     "SocialAuthenticationRequest",
     "GetAllUserRequest",
     "GetAllUserResponse",
-    "OrganizationError",
     "CreateOrganizationRequest",
     "UpdateOrganizationRequest",
     "GetOrganizationRequest",
@@ -606,18 +562,15 @@ __all__ = [
     "Metadata",
     "Argument",
     "Variable",
-    "Provider",
     "Tag",
     "Organization",
     "Metric",
-    "Content",
     "ProtoMessage",
     "ToolCall",
     "FunctionCall",
     "Knowledge",
     "TextPrompt",
     "TextChatCompletePrompt",
-    "AssistantMessageStage",
     "AssistantConversationMessage",
     "AssistantConversationContext",
     "AssistantConversation",
@@ -638,12 +591,8 @@ __all__ = [
     "GetAssistantWebhookLogRequest",
     "GetAssistantWebhookLogResponse",
     "GetAllAssistantWebhookLogResponse",
-    "KnowledgeConnectRequest",
-    "KnowledgeConnectResponse",
     "GeneralConnectRequest",
     "GeneralConnectResponse",
-    "ActionConnectRequest",
-    "ActionConnectResponse",
     "GetConnectorFilesRequest",
     "GetConnectorFilesResponse",
     "EndpointAttribute",
@@ -743,11 +692,26 @@ __all__ = [
     "UpdateAssistantDetailRequest",
     "GetAssistantConversationRequest",
     "GetAssistantConversationResponse",
-    "AssistantConversationMessageTextContent",
-    "AssistantConversationMessageAudioContent",
     "AgentKitStub",
     "AgentKit",
     "AgentKitServicer",
     "TalkServiceServicer",
     "add_AgentKitServicer_to_server",
+    # Agent Kit
+    "AgentKitAgent",
+    "AgentKitServer",
+    "SSLConfig",
+    "AuthConfig",
+    "AuthorizationInterceptor",
+    "AssistantTalkInput",
+    "AssistantTalkOutput",
+    "TalkInput",
+    "TalkOutput",
+    "ConversationAssistantMessage",
+    "ConversationConfiguration",
+    "ConversationDirective",
+    "ConversationInterruption",
+    "ConversationUserMessage",
+    "ConversationToolCall",
+    "ConversationToolResult"
 ]
